#================================================================================
#   Copyright (C) 2022, Heartland Data inc. All Rights Reserved. 
#
#   Title  :   Ethernet Driver
#   EventID:   Via the driver
#   AppVer :   DT+ Ver2.00 -
#   FileID :   36bC2
#   Version:   1.0
#   Author :   HLDC
#================================================================================
import struct
import ctypes

DtTestPoint_DriverLib = ctypes.cdll.LoadLibrary("./dt_lib.so") # Customize its pass

#MIN/MAX Value
INT32_MAX = 2147483647
INT32_MIN = -2147483648

#================================================================================
#   Func : DtTestPoint
#   Desc : Test Point output function.
#================================================================================
def DtTestPoint(addr: int, dat: int):
    DtTestPoint_DriverLib._TP_BusOut(addr, dat)

#================================================================================
#   Func : DtTestPointValue
#   Desc : Variable Test Point output function.
#================================================================================
def DtTestPointValue(addr: int, dat: int, value, length:int = 0):

    if(isinstance(value, int)):
        if INT32_MIN <= value <= INT32_MAX:
            length = 4 #4Byte以下
        else:
            length = 8 #4Byteより大きい
        c_value = ctypes.c_void_p(value)
    elif(isinstance(value, float)):
        length = 8
        c_value = ctypes.c_double(value)
    elif(isinstance(value, bool)):
        length = 1
        c_value = ctypes.c_bool(value)
#    elif(isinstance(value, str)):
#    elif(isinstance(value, tuple)):
#    elif(isinstance(value, list)):
    else:
        print('[DT+Trace ValueTP Error] : This type is unsupporeted or value is None')
        return
            
    DtTestPoint_DriverLib._TP_MemoryOutput(addr, dat, ctypes.byref(c_value), length)

